pub struct TigerResource {
pub uri: String,
pub geoid_type: GeoidType,
pub file_scope: Option<GeoidType>,
}Expand description
represents everything about a TIGER/Lines shapefile needed to download it and represent the result with bamcensus types.
Fields
uri: Stringcomplete URI to a file location in the TIGER/LINES HTTP website
geoid_type: GeoidTypethe geoid type of the file contents. each row should have a column denoting the Geoid value as a string that can be decoded by this application using the GeoidType::geoid_from_string method.
file_scope: Option<GeoidType>the file will contain a geographical data collection. the scope of that file depends on the TIGRIS year and target geoid hierarchy. for example, in 2010, county subdivisions are stored in files organized by state/state code, so their file scope would be State and the file itself would just be tagged by the state code. if file_scope is None, then the scope is “national”, as in, there is one file for all values for this year.
Implementations
Sourceimpl TigerResource
impl TigerResource